==> developer-center-api-3.4.21-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorAppSkinDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by dugq on 2018/8/13.
 */
public class VisualEditorAppSkinDto implements Serializable {
    private static final long serialVersionUID = -6410233072724568540L;



    /**
     * 主键
     * 逻辑主键
     * isNullAble:0
     */
    private Long id;

    /**
     * 开发者id
     * isNullAble:0,defaultVal:0
     */
    private Long developerId;

    /**
     * 应用id
     * isNullAble:0,defaultVal:0
     */
    private Long appId;

    /**
     * js链接
     * isNullAble:1
     */
    private String jsUrl;

    /**
     * 页面组件数据
     * isNullAble:1
     */
    private String dataJson;

    /**
     * 皮肤名称
     * isNullAble:1
     */
    private String skinName;

    /**
     * 标识位(参考statusSwitch)
     * isNullAble:0,defaultVal:0
     */
    private Integer openStatus;

    /**
     * 组件内容数据md5
     * isNullAble:1
     */
    private String unitDataMd5;

    /**
     * 皮肤类型(首页皮肤,活动皮肤)
     * isNullAble:1
     */
    private Integer skinType;

    /**
     * 皮肤类型，是否临时数据
     *
     */
    private Integer skinMode;
    /**
     * 临时数据的原数据id
     */
    private Long parentId;

    /**
     * 删除标志位(0-正常 1-删除)
     * isNullAble:0,defaultVal:0
     */
    private Integer deleted;

    /**
     * 修改时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    /**
     * 创建时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtCreate;


    public Integer getSkinMode() {
        return skinMode;
    }

    public void setSkinMode(Integer skinMode) {
        this.skinMode = skinMode;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public void setId(Long id){this.id = id;}

    public Long getId(){return this.id;}

    public void setDeveloperId(Long developerId){this.developerId = developerId;}

    public Long getDeveloperId(){return this.developerId;}

    public void setAppId(Long appId){this.appId = appId;}

    public Long getAppId(){return this.appId;}

    public void setJsUrl(String jsUrl){this.jsUrl = jsUrl;}

    public String getJsUrl(){return this.jsUrl;}

    public void setDataJson(String dataJson){this.dataJson = dataJson;}

    public String getDataJson(){return this.dataJson;}

    public void setSkinName(String skinName){this.skinName = skinName;}

    public String getSkinName(){return this.skinName;}

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public void setUnitDataMd5(String unitDataMd5){this.unitDataMd5 = unitDataMd5;}

    public String getUnitDataMd5(){return this.unitDataMd5;}

    public void setSkinType(Integer skinType){this.skinType = skinType;}

    public Integer getSkinType(){return this.skinType;}

    public void setDeleted(Integer deleted){this.deleted = deleted;}

    public Integer getDeleted(){return this.deleted;}

    public void setGmtModified(Date gmtModified){this.gmtModified = gmtModified;}

    public Date getGmtModified(){return this.gmtModified;}

    public void setGmtCreate(Date gmtCreate){this.gmtCreate = gmtCreate;}

    public Date getGmtCreate(){return this.gmtCreate;}
    @Override
    public String toString() {
        return "VisualEditorAppSkin{" +
                "id='" + id + '\'' +
                "developerId='" + developerId + '\'' +
                "appId='" + appId + '\'' +
                "jsUrl='" + jsUrl + '\'' +
                "dataJson='" + dataJson + '\'' +
                "skinName='" + skinName + '\'' +
                "statusSwitch='" + openStatus + '\'' +
                "unitDataMd5='" + unitDataMd5 + '\'' +
                "skinType='" + skinType + '\'' +
                "deleted='" + deleted + '\'' +
                "gmtModified='" + gmtModified + '\'' +
                "gmtCreate='" + gmtCreate + '\'' +
                '}';
    }

}

==> developer-center-api-3.6.17-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorAppSkinDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by dugq on 2018/8/13.
 */
public class VisualEditorAppSkinDto implements Serializable {
    private static final long serialVersionUID = -6410233072724568540L;



    /**
     * 主键
     * 逻辑主键
     * isNullAble:0
     */
    private Long id;

    /**
     * 开发者id
     * isNullAble:0,defaultVal:0
     */
    private Long developerId;

    /**
     * 应用id
     * isNullAble:0,defaultVal:0
     */
    private Long appId;

    /**
     * js链接
     * isNullAble:1
     */
    private String jsUrl;

    /**
     * 页面组件数据
     * isNullAble:1
     */
    private String dataJson;

    /**
     * 皮肤名称
     * isNullAble:1
     */
    private String skinName;

    /**
     * 标识位(参考statusSwitch)
     * isNullAble:0,defaultVal:0
     */
    private Integer openStatus;

    /**
     * 组件内容数据md5
     * isNullAble:1
     */
    private String unitDataMd5;

    /**
     * 皮肤类型(首页皮肤,活动皮肤)
     * isNullAble:1
     */
    private Integer skinType;

    /**
     * 皮肤类型，是否临时数据
     *
     */
    private Integer skinMode;
    /**
     * 临时数据的原数据id
     */
    private Long parentId;

    /**
     * 删除标志位(0-正常 1-删除)
     * isNullAble:0,defaultVal:0
     */
    private Integer deleted;

    /**
     * 修改时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtModified;

    /**
     * 创建时间
     * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    private String extraField;


    public Integer getSkinMode() {
        return skinMode;
    }

    public void setSkinMode(Integer skinMode) {
        this.skinMode = skinMode;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public void setId(Long id){this.id = id;}

    public Long getId(){return this.id;}

    public void setDeveloperId(Long developerId){this.developerId = developerId;}

    public Long getDeveloperId(){return this.developerId;}

    public void setAppId(Long appId){this.appId = appId;}

    public Long getAppId(){return this.appId;}

    public void setJsUrl(String jsUrl){this.jsUrl = jsUrl;}

    public String getJsUrl(){return this.jsUrl;}

    public void setDataJson(String dataJson){this.dataJson = dataJson;}

    public String getDataJson(){return this.dataJson;}

    public void setSkinName(String skinName){this.skinName = skinName;}

    public String getSkinName(){return this.skinName;}

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public void setUnitDataMd5(String unitDataMd5){this.unitDataMd5 = unitDataMd5;}

    public String getUnitDataMd5(){return this.unitDataMd5;}

    public void setSkinType(Integer skinType){this.skinType = skinType;}

    public Integer getSkinType(){return this.skinType;}

    public void setDeleted(Integer deleted){this.deleted = deleted;}

    public Integer getDeleted(){return this.deleted;}

    public void setGmtModified(Date gmtModified){this.gmtModified = gmtModified;}

    public Date getGmtModified(){return this.gmtModified;}

    public void setGmtCreate(Date gmtCreate){this.gmtCreate = gmtCreate;}

    public Date getGmtCreate(){return this.gmtCreate;}

    public String getExtraField() {
        return extraField;
    }

    public void setExtraField(String extraField) {
        this.extraField = extraField;
    }

    @Override
    public String toString() {
        return "VisualEditorAppSkin{" +
                "id='" + id + '\'' +
                "developerId='" + developerId + '\'' +
                "appId='" + appId + '\'' +
                "jsUrl='" + jsUrl + '\'' +
                "dataJson='" + dataJson + '\'' +
                "skinName='" + skinName + '\'' +
                "statusSwitch='" + openStatus + '\'' +
                "unitDataMd5='" + unitDataMd5 + '\'' +
                "skinType='" + skinType + '\'' +
                "deleted='" + deleted + '\'' +
                "gmtModified='" + gmtModified + '\'' +
                "gmtCreate='" + gmtCreate + '\'' +
                "extraField='" + extraField + '\'' +
                '}';
    }

}
